
# hist.gp
# Andrew Davison, ad@fivedots.coe.psu.ac.th, April 2019


# Plot a histogram of three kinds of network activity.

# Each plot is drawn twice, once using dumb terminal
# output and then as a PNG.

# The plot is repeatedly redrawn, controlled by
# gnuplot waiting for a value to arrive from a
# shell script

# Between each replot, the datafile (stored in datafnm)
# is updated by the controlling shell script.

# Some recent features of Gnuplot are used, and so
# the latest software version should be installed.



set macros
readInt = "int(system(\"read n; echo \$n\"))"
readDate = "system(\"echo \$(date +%H:%M:%S)\")"


set terminal dumb size 40 20

# set plotting attributes
set boxwidth 0.3
set border 3       # only left and bottom axes shown
set xtics nomirror
set ytics nomirror
set tics out
set xtics scale 0
set ytics scale 0.5

set yrange [0:*]

set title "No. of Connected Types"
set key outside center top


count = @readInt    # wait for an integer message from shell script
                    # count is used to label the PNG files

while (count >= 0) {   # -ve can be used to signal the shell's end
  plot datafnm using 2:xtic(1) notitle with boxes, \
            '' using 0:2:2 title @readDate with labels center
    # datafnm is the input argument from the shell script

  call "savePNG.gp" count  
  set terminal dumb; set output  # revert to dumb

  count = @readInt      # wait for shell script
}

