
# points.gp
# Andrew Davison, ad@fivedots.coe.psu.ac.th, April 2019


# Plot a series of data points of network activity.
# The x-axis is the current time in minutes:seconds.
# Each point is labelled with its y-value.

# Each plot is drawn twice, once using dumb terminal
# output and then as a PNG.

# The plot is repeatedly redrawn, controlled by
# gnuplot waiting for a value to arrive from a 
# shell script

# Between each replot, the datafile (stored in datafnm)
# is updated by the controlling shell script.

# Some recent features of Gnuplot are used, and so
# the latest software version should be installed.


set macros
readInt = "int(system(\"read n; echo \$n\"))"
readDate = "system(\"echo \$(date +%d-%b%t%I%P)\")"

set terminal dumb size 60, 20

# set plotting attributes
set border 3       # only left and bottom axes shown
set xtics nomirror
set ytics nomirror
# set tics out scale 0.5, 0
set tics out 

# x- and y- axes data formats
set xdata time
set timefmt '%s'       # epoch seconds
set format x '%M:%S'   # shown as minutes ":" seconds
set yrange [0:*]

set title "No. of Connections"
set key outside center top


count = 0  # used to uniquely label the PNG files

val = @readInt    # wait for an integer message from shell script
                  # val is not used in this program

while (val >= 0) {    # -ve can be used to signal the shell's end
  plot datafnm using 1:2 notitle with dots, \
         '' using 1:2:2 title @readDate  \
                  with labels point pt 24 offset 0,1
  # datafnm is the input argument from the shell script

  call "savePNG.gp" count
  set terminal dumb; set output    # revert to dumb

  val = @readInt    # wait for shell script 
  count = count+1
}

